If KVM memory protection is active, the trampoline area will need to be
in shared memory.

Signed-off-by: Kirill A. Shutemov <kirill.shute...@linux.intel.com>
---
 arch/x86/realmode/init.c | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)

diff --git a/arch/x86/realmode/init.c b/arch/x86/realmode/init.c
index 1ed1208931e0..7392940a7f96 100644
--- a/arch/x86/realmode/init.c
+++ b/arch/x86/realmode/init.c
@@ -9,6 +9,7 @@
 #include <asm/realmode.h>
 #include <asm/tlbflush.h>
 #include <asm/crash.h>
+#include <asm/kvm_para.h>
 
 struct real_mode_header *real_mode_header;
 u32 *trampoline_cr4_features;
@@ -55,11 +56,11 @@ static void __init setup_real_mode(void)
        base = (unsigned char *)real_mode_header;
 
        /*
         * If SME is active, the trampoline area will need to be in
         * decrypted memory in order to bring up other processors
         * successfully. This is not needed for SEV.
         */
-       if (sme_active())
+       if (sme_active() || kvm_mem_protected())
                set_memory_decrypted((unsigned long)base, size >> PAGE_SHIFT);
 
        memcpy(base, real_mode_blob, size);
@@ -55,11 +56,11 @@ static void __init setup_real_mode(void)
 
        /*
-        * If SME is active, the trampoline area will need to be in
-        * decrypted memory in order to bring up other processors
+        * If SME or KVM memory protection is active, the trampoline area will
+        * need to be in decrypted memory in order to bring up other processors
         * successfully. This is not needed for SEV.
         */
-- 
2.26.2

Reply via email to